@@ -65,4 +65,22 @@ inv
 
 
 
+//! delayed matrix inverse (symmetric matrices)
+template<typename T1>
+arma_inline
+const Op<T1, op_inv_sym>
+inv
+  (
+  const Op<T1, op_symmat>& X,
+  const typename arma_blas_type_only<typename T1::elem_type>::result* junk = 0
+  )
+  {
+  arma_extra_debug_sigprint();
+  arma_ignore(junk);
+  
+  return Op<T1, op_inv_sym>(X.m, X.aux_u32_a, 0);
+  }
+
+
+
 //! @}
